==> Squeak3.0.2-MacOSX-VM.tar.gz: Squeak-MacOSX-VM-3.0.2-2001.04.16.sb/src/CocoaSqueak/Document.m <==
// Document.m

#import "Document.h"
#import <Squeak/AccessorMacros.h>
#import <Squeak/SqueakInterpreter.h>
#import <Squeak/SqueakObjcInterpreter.h>
#import <SqueakAppKit/SqClipboardHandler.h>
#import <SqueakAppKit/SqueakSoundServer.h>


@implementation Document



accessor( view, setView )
accessor( interpreter, setInterpreter )

// -----------------------------------------------------------------------------
// Override returning the nib file name of the document

- (NSString *)windowNibName {
    // If you need to use a subclass of NSWindowController or if your document supports multiple NSWindowControllers, you should remove this method and override -makeWindowControllers instead.
    return @"Document";
}

// -----------------------------------------------------------------------------
// Override

- (void)windowControllerDidLoadNib:(NSWindowController *) aController{
    [super windowControllerDidLoadNib:aController];

    [[view window] setContentView:view];
    [[view window] setAcceptsMouseMovedEvents:YES];
//    [[view window] setTitle:imagePath];
    [view setInterpreter:interpreter];
    [interpreter startInterpreterInSeparateThread];
    [view becomeFirstResponder];
}

// -----------------------------------------------------------------------------
// Override

- (NSData *)dataRepresentationOfType:(NSString *)aType {
    return nil;
}


-(void)startInterpreterWithImageInPath:imagePath heapSize:(int)heapSize
{
    id vmPath;

    [interpreter readImageFile:imagePath withHeapSize:heapSize];

    vmPath= [[imagePath stringByDeletingLastPathComponent] stringByAppendingString:@"/"];
    if ( [vmPath isEqual:@""] ) {
        vmPath=@"./";
    }
    [interpreter setVmPath:vmPath];
    [interpreter setStackCacheEntries:64];
    [interpreter setContextCacheEntries:64];
    [interpreter setClipHandler:[[[SqClipboardHandler alloc] init] autorelease]];
    [interpreter setSoundServer:[[[SqueakSoundServer alloc] init] autorelease]];
    [self updateChangeCount:NSChangeDone];
}

-(int)defaultHeapSize
{
    int mb = [[NSUserDefaults standardUserDefaults] integerForKey:@"HeapSize"];
    if ( mb < 1 ) {
        mb=16;
    }
    return mb*1024*1024;
}

-defaultImagePath
{
    return [[NSUserDefaults standardUserDefaults] stringForKey:@"imagePath"];
}

-(void)setDefaultImagePath:imagePath
{
    if ( ![imagePath isEqual:[self defaultImagePath]] ) {
        [[self window] setTitle:imagePath];
        [[NSUserDefaults standardUserDefaults] setObject:imagePath forKey:@"imagePath"];
        [[NSUserDefaults standardUserDefaults] synchronize];
    }
}


-(void)startInterpreterWithDefaultParameters
{
    [self startInterpreterWithImageInPath:[self defaultImagePath] heapSize:[self defaultHeapSize]];
}

-interpreterClass
{
    return [[NSUserDefaults standardUserDefaults] boolForKey:@"UseObjcInterpreter"] ?
    [SqueakObjcInterpreter class] : [SqueakInterpreter class];
}

- (BOOL)readFromFile:(NSString *)fileName ofType:(NSString *)docType {
    Class interpreterClass = [self interpreterClass];
    id interp=[interpreterClass interpreter];
    if ( [docType isEqual:@"SqueakImage"] && fileName &&
         ![interp interpreterRunning]) {
        interpreter = interp;
        [self startInterpreterWithImageInPath:fileName heapSize:[self defaultHeapSize]];
        return YES;
    } else {
        return NO;
    }
}

-(void)dealloc
{
    [interpreter stopInterpreter];
    [view release];
    [super dealloc];
}

- (NSSize)windowWillResize:(NSWindow *)sender toSize:(NSSize)frameSize
{
    int viewToWindowWidth = [sender frame].size.width - [view frame].size.width;
    frameSize.width = ((int)((frameSize.width- viewToWindowWidth ) + 31) & ~31) + viewToWindowWidth;
    [view setDirty:YES];
    return frameSize;
}


@end

==> Squeak3.0.3-MacOSX-VM.tar.gz: Squeak-MacOSX-VM-3.0.3-2001.06.05.sb/src/CocoaSqueak/Document.m <==
// Document.m

#import "Document.h"
#import <Squeak/AccessorMacros.h>
#import <Squeak/SqueakInterpreter.h>
#import <Squeak/SqueakObjcInterpreter.h>
#import <SqueakAppKit/SqClipboardHandler.h>
#import <SqueakAppKit/SqueakSoundServer.h>


@implementation Document


idAccessor( view , setView )
idAccessor( interpreter, setInterpreter )

// -----------------------------------------------------------------------------
// Override returning the nib file name of the document

- (NSString *)windowNibName {
    // If you need to use a subclass of NSWindowController or if your document supports multiple NSWindowControllers, you should remove this method and override -makeWindowControllers instead.
    return @"Document";
}

// -----------------------------------------------------------------------------
// Override

- (void)windowControllerDidLoadNib:(NSWindowController *) aController{
    [super windowControllerDidLoadNib:aController];

    [[view window] setContentView:view];
    [[view window] setAcceptsMouseMovedEvents:YES];
//    [[view window] setTitle:imagePath];
    [view setInterpreter:interpreter];
    [interpreter startInterpreterInSeparateThread];
    [view becomeFirstResponder];
}

// -----------------------------------------------------------------------------
// Override

- (NSData *)dataRepresentationOfType:(NSString *)aType {
    return nil;
}


-(void)startInterpreterWithImageInPath:imagePath heapSize:(int)heapSize
{
    id vmPath;

    [interpreter readImageFile:imagePath withHeapSize:heapSize];

    vmPath= [[imagePath stringByDeletingLastPathComponent] stringByAppendingString:@"/"];
    if ( [vmPath isEqual:@""] ) {
        vmPath=@"./";
    }
    [interpreter setVmPath:vmPath];
    [interpreter setStackCacheEntries:64];
    [interpreter setContextCacheEntries:64];
    [interpreter setClipHandler:[[[SqClipboardHandler alloc] init] autorelease]];
    [interpreter setSoundServer:[[[SqueakSoundServer alloc] init] autorelease]];
    [self updateChangeCount:NSChangeDone];
}

-(int)defaultHeapSize
{
    int mb = [[NSUserDefaults standardUserDefaults] integerForKey:@"HeapSize"];
    if ( mb < 1 ) {
        mb=16;
    }
    return mb*1024*1024;
}

-defaultImagePath
{
    return [[NSUserDefaults standardUserDefaults] stringForKey:@"imagePath"];
}

-(void)setDefaultImagePath:imagePath
{
    if ( ![imagePath isEqual:[self defaultImagePath]] ) {
        [[self window] setTitle:imagePath];
        [[NSUserDefaults standardUserDefaults] setObject:imagePath forKey:@"imagePath"];
        [[NSUserDefaults standardUserDefaults] synchronize];
    }
}


-(void)startInterpreterWithDefaultParameters
{
    [self startInterpreterWithImageInPath:[self defaultImagePath] heapSize:[self defaultHeapSize]];
}

-interpreterClass
{
    return [[NSUserDefaults standardUserDefaults] boolForKey:@"UseObjcInterpreter"] ?
    [SqueakObjcInterpreter class] : [SqueakInterpreter class];
}

- (BOOL)readFromFile:(NSString *)fileName ofType:(NSString *)docType {
    Class interpreterClass = [self interpreterClass];
    id interp=[interpreterClass interpreter];
    if ( [docType isEqual:@"SqueakImage"] && fileName &&
         ![interp interpreterRunning]) {
        interpreter = interp;
        [self startInterpreterWithImageInPath:fileName heapSize:[self defaultHeapSize]];
        return YES;
    } else {
        return NO;
    }
}

-(void)dealloc
{
    [interpreter stopInterpreter];
    [view release];
    [super dealloc];
}

- (NSSize)windowWillResize:(NSWindow *)sender toSize:(NSSize)frameSize
{
    int viewToWindowWidth = [sender frame].size.width - [view frame].size.width;
    frameSize.width = ((int)((frameSize.width- viewToWindowWidth ) + 31) & ~31) + viewToWindowWidth;
    [view setDirty:YES];
    return frameSize;
}


@end
